atomate.utils.tests package — atomate 0.9.2 documentation

# atomate.utils.tests package

## Submodules

## atomate.utils.tests.test_loaders module

class `atomate.utils.tests.test_loaders.` `FuncTest`(methodName='runTest')

  Bases: `pymatgen.util.testing.PymatgenTest`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_get_wf_from_spec_dict`()
  `test_multi_parent`()

## atomate.utils.tests.test_utils module

class `atomate.utils.tests.test_utils.` `Task1`(*args, **kwargs)

  Bases: `fireworks.core.firework.FiretaskBase`

  `run_task`(fw_spec)

    This method gets called when the Firetask is run. It can take in a Firework spec, perform some task using that data, and then return an output in the form of a FWAction.

    Args:
      fw_spec (dict): A Firework spec. This comes from the master spec.

        In addition, this spec contains a special “_fw_env” key that contains the env settings of the FWorker calling this method. This provides for abstracting out certain commands or settings. For example, “foo” may be named “foo1” in resource 1 and “foo2” in resource 2. The FWorker env can specify { “foo”: “foo1”}, which maps an abstract variable “foo” to the relevant “foo1” or “foo2”. You can then write a task that uses fw_spec[“_fw_env”][“foo”] that will work across all these multiple resources.

    Returns:

      (FWAction)

class `atomate.utils.tests.test_utils.` `Task2`(*args, **kwargs)

  Bases: `fireworks.core.firework.FiretaskBase`

  `run_task`(fw_spec)

    This method gets called when the Firetask is run. It can take in a Firework spec, perform some task using that data, and then return an output in the form of a FWAction.

    Args:
      fw_spec (dict): A Firework spec. This comes from the master spec.

        In addition, this spec contains a special “_fw_env” key that contains the env settings of the FWorker calling this method. This provides for abstracting out certain commands or settings. For example, “foo” may be named “foo1” in resource 1 and “foo2” in resource 2. The FWorker env can specify { “foo”: “foo1”}, which maps an abstract variable “foo” to the relevant “foo1” or “foo2”. You can then write a task that uses fw_spec[“_fw_env”][“foo”] that will work across all these multiple resources.

    Returns:

      (FWAction)

class `atomate.utils.tests.test_utils.` `UtilsTests`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `setUp`(lpad=True)

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  `test_env_chk`()
  `test_get_database`()
  `test_get_mongolike`()
  `test_get_uri`()
  `test_recursive_get_result`()
  `test_recursiveupdate`()

## Module contents